*

*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*

*-------
* What is the number and percentage of post-conflict episodes with new PGMs?
*-------

*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
	clear	all
	set		more off


*-------------------
* Opend dataset 
*-------------------
	use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
	sort	gwno year
	tsset	gwno year


* Drop episodes longer than 10 years
	drop if peace_years > 10

* Drop countrie swith no PGM inforamtion
	drop if pgm_presence == .

* Collapse the data at the post-conflict episode level
	#delimit ;
	collapse (max) 	pgm_presence
					pgm_new_postconf_dummy
					, by(peace_id)
	;
	#delimit cr


* Generate count of all episodes
	gen count = _N
	gen id_collapse = 1

	#delimit ;
	collapse (sum) 	pgm_presence
					pgm_new_postconf_dummy
			 (max)	count
					, by(id_collapse)
	;
	#delimit cr


* Generate percentages
	gen presence_percent = (pgm_presence*100)/count
	gen new_pgm_percent = (pgm_new_postconf_dummy*100)/count 







*<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>*

* The following code reflects the dristirbution of the 25 post-conflict episodes
* for which there are NEW PGMs

*-------
* Dummy variables to identify each scenario per country-episode-year
*-------

*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
	clear	all
	set		more off


*-------------------
* Opend dataset 
*-------------------
	use 	"Data/cg_postconflict_data", clear


*-------------------
* Sort data
*-------------------
	sort	gwno year
	tsset	gwno year




* Dummy for PGM new only
	gen new_pgm_only = 0

	#delimit ;
	replace new_pgm_only = 1 if 
			pgm_presence == 1 &
			pgm_warlegacy_dummy == 0 &
			pgm_new_postconf_dummy == 1
	;
	#delimit cr

	tab new_pgm_only



* Dummy for PGM new and old but not simultaneously present (substitute)
	gen old_pgm_only = 0

	#delimit ;
	replace old_pgm_only = 1 if 
			pgm_presence == 1 &
			pgm_warlegacy_dummy == 1 &
			pgm_new_postconf_dummy == 0
	;
	#delimit cr

	tab old_pgm_only 



* Dummy for PGM new + inherited simultaneously (complement)
	gen new_old_pgm = 0

	#delimit ;
	replace new_old_pgm = 1 if 
			pgm_presence == 1 &
			pgm_warlegacy_dummy == 1 &
			pgm_new_postconf_dummy == 1
	;
	#delimit cr

	tab new_old_pgm


*-------
* Collapse information at the conflict episode level
*-------
/*
Note (!): information to distinguish between the three scenarios
	*- Scenario 1 (only new):   If episode has only information on new_pgm_only == 1
	*- Scenario 2 (substitute): If episode has information on the individual
	*							variables new_pgm_only == 1 & old_pgm_only == 1
	*- Scenario 3 (complements): If  episode has information on new_old_pgm == 1
	
Important (!) if a single episode has information for several of this variables
			  the herarchy to choose the scenatio is as follows:
	*- Scenario 3 > Scenario 2 
	*- Scenario 3 > Scenario 1
	*- Scenario 2 > Scenario 1
	*- Scenario 1 only possible if variable new_pgm_only alone == 1
*/


* Keep only post-conflict episodes upto 10 years
	drop if peace_years>10

* Keep only post-conflict episodes with PGMs
	drop if pgm_presence == 0
	drop if pgm_presence == .


* Collapse the data
	#delimit ;
	collapse (max) 	new_pgm_only
					old_pgm_only
					new_old_pgm
					last_year = year
			  (min) first_year = year
			(firstnm) country		
			, by(peace_id)
	;
	#delimit cr



* Drop cases that only have conflict inherited PGMs
	#delimit ;
	drop if new_pgm_only == 0 &
			old_pgm_only == 1 &
			new_old_pgm  == 0
	;
	#delimit cr


* Generate scenarios

	* Secnario 1: country only with NEW PGMS
		gen scenario_1 = 0
		#delimit ;
		replace scenario_1 = 1 if 
				new_pgm_only == 1 &
				old_pgm_only == 0 &
				new_old_pgm  == 0
		;
		#delimit cr
		
	
	* Secnario 2: government has inherited and then new PGM (substitution) not simultaneously
		gen scenario_2 = 0
		#delimit ;
		replace scenario_2 = 1 if 
				new_pgm_only == 1 &
				old_pgm_only == 1 &
				new_old_pgm  == 0
		;
		#delimit cr
		
		
	* Secnario 3: government has simultaneously inherited and then new PGM (complement)
		gen scenario_3 = 0
		#delimit ;
		replace scenario_3 = 1 if 
				new_pgm_only == 0 &
				old_pgm_only == 0 &
				new_old_pgm  == 1
		;
		#delimit cr
		#delimit ;
		replace scenario_3 = 1 if 
				new_pgm_only == 0 &
				old_pgm_only == 1 &
				new_old_pgm  == 1
		;
		#delimit cr
	
	
* Scenario 2 seems not to exist!



* There are 22 distinctive countries. 
* Repeated countries only one 2 entrances are: Liberia, Pakistan and Bangladesh

* Collapse information to get percentages
	gen total = _N

	gen id_collapse = 1


	#delimit ;
	collapse (sum) 	scenario_*
			 (max)  total 		
			, by(id_collapse)
	;
	#delimit cr



* Generate percentages
	#delimit ;
	foreach var of varlist scenario*{;
		gen percent_`var'= (`var'*100)/total;
	};
	;
	#delimit cr


* Note: scenario 1 = 8 (32%), scenario 3 = 17 (68%)

* Do plot: 
		
		* Keep variables with percentages
		  keep percent_scenario_*

		  
		* Reshape data
		 gen id = 1
		 reshape long percent_scenario, i(id) j(scenario) string
		 replace id = 2 if scenario == "_2"
		 replace id = 3 if scenario == "_3"
		 drop scenario
		 rename id scenario
		 
		* Generate minimum and maximum values
		  gen min = 0
		  gen max = 100
		  gen x = 0
		  
		* Plot
		  #delimit ;
		  twoway  	rbar min percent_scenario x if scenario == 3 , col(gs0) barwidth(.07) horizontal ||
		            rbar percent_scenario max x if scenario == 3 , col(gs10) barwidth(.07) horizontal
					title("", size(medlarge) ring(10)) 
					xtitle("", height(5))
					ytitle("", orientation(vertical) height(5))
					yscale(range(0 0.1) noline )
					xscale(range(0.5 4.5) noextend)
					xlabel(0(5)100, angle(horizontal) nogrid labsize(small)) xmtick(##5)
					ylabel( "", angle(horizontal) nogrid labsize(small)) 
					legend(off)
					text(0.025 15 "% Post-conflict countries with""inherited and new PGMs", j(left) col(white))
					text(0.025 82 "% Post-conflict countries with""only new PGMs", j(left) col(white))
					ysize(1) xsize(2)  
					graphregion(margin(small) color(white)) 
					scheme(s2mono)
			;
			# delimit cr

graph export "Figures/cg_country_profile_pgm_new.pdf", as(pdf) replace



*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
