
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off



*-------------------
* Opend dataset 
*-------------------
use     "Data/cg_pgm_postconflict_years"


* Clear code
replace pgm_inf = 1 if pgm_unclear == 1
drop pgm_unclear

** Corroborate code
br if pgm_inf == pgm_semi
br if pgm_warlegacy == pgm_newpostconf


** Generate count
gen count = 1



** Comment the following out if preferred time-variant table

		**  Find duplicates: this is the case at different points in time
		sort pgm_id
		br if pgm_id[_n]==pgm_id[_n-1]

			* See that they have different characteristics
				* Those that are twice or more in the data
				#delimit ;
				gen marker = 1 if pgm_id[_n]==pgm_id[_n-1]
				;
				#delimit cr
			
				* Those that have different characteristics
				#delimit ;
				gen marker2 = 1 if pgm_id[_n]==pgm_id[_n-1] &
							  pgm_inf[_n]!=pgm_inf[_n-1] |
							  pgm_id[_n]==pgm_id[_n-1] &
							  pgm_warlegacy[_n]!=pgm_warlegacy[_n-1]
				;
				#delimit cr
			
				* Drop those that marker == 1 but are not different
				drop if marker == 1 & marker2 == .
				
				
				* Corroborate with target data
				* merge m:m pgm_id using "Data\cg_pgm_old__new_target_list_RR.dta"

* End of comment out section for time-variant output.

				
** Generate possible combinations: row numbers for government relation
*gen pgm_combo = .
*replace pgm_combo = 1 if pgm_semi == 1 & pgm_warlegacy == 1
*replace pgm_combo = 2 if pgm_semi == 1 & pgm_newpostconf == 1
*replace pgm_combo = 3 if pgm_inf == 1 & pgm_warlegacy == 1
*replace pgm_combo = 4 if pgm_inf == 1 & pgm_newpostconf == 1 


** Generate possible combinations: row number to war relation
gen pgm_combo2 = .
replace pgm_combo2 = 1 if pgm_warlegacy == 1 & pgm_semi == 1
replace pgm_combo2 = 2 if pgm_warlegacy == 1 & pgm_inf == 1
replace pgm_combo2 = 3 if pgm_newpostconf == 1 & pgm_semi == 1
replace pgm_combo2 = 4 if pgm_newpostconf == 1 & pgm_inf == 1 

** Collapse data
#delimit;
collapse (sum) count
			   , by(pgm_combo2)
;
#delimit cr


** Label iformation
*gen name_combo = ""
*replace name_combo = "Semi-Old" if pgm_combo == 1
*replace name_combo = "Semi-New" if pgm_combo == 2
*replace name_combo = "Inf-Old" if pgm_combo == 3
*replace name_combo = "Inf-New" if pgm_combo == 4

gen name_combo2 = ""
replace name_combo = "Old-Semi" if pgm_combo == 1
replace name_combo = "Old-Inf" if pgm_combo == 2
replace name_combo = "New-Semi" if pgm_combo == 3
replace name_combo = "New-Inf" if pgm_combo == 4


** Row percentages
egen total_row1 = sum(count) if pgm_combo2<3
egen total_row2 = sum(count) if pgm_combo2>2

gen percent_row1 = (count*100)/total_row1
gen percent_row2 = (count*100)/total_row2


** Total: percentages
egen total = sum(count)

** Total: generate percentages
*gen percent = (count*100)/total


*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
