
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off


*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year


*------------------------------------------------------------------------------*
* MODELS PGM OLD vs NEW
*------------------------------------------------------------------------------*


*------------------------------------------------------------------------------*
* Model A  exclude spells of max 1 year
*------------------------------------------------------------------------------*
version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10 & spell_peace_max!= 1, cl(gwno)
;
#delimit cr
estimates store model1jnOLD


* Corroborate that the exclusion was correct
tab spell_peace_max if e(sample) == 1
*





*------------------------------------------------------------------------------*
* Model A  exclude spells of max 2 years
*------------------------------------------------------------------------------*
version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10 & spell_peace_max!= 1 
							 & spell_peace_max!= 2, cl(gwno)
;
#delimit cr
estimates store modelfrom1to2jnOLD


* Corroborate that the exclusion was correct
tab spell_peace_max if e(sample) == 1





*------------------------------------------------------------------------------*
* Model A  exclude spells of max 3 years
*------------------------------------------------------------------------------*
version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10 & spell_peace_max!= 1 
							 & spell_peace_max!= 2 
							 & spell_peace_max!= 3, cl(gwno)
;
#delimit cr
estimates store modelfrom1to3jnOLD


* Corroborate that the exclusion was correct
tab spell_peace_max if e(sample) == 1




*------------------------------------------------------------------------------*
* Model A  exclude spells of max 4 years
*------------------------------------------------------------------------------*
version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10 & spell_peace_max!= 1 
							 & spell_peace_max!= 2 
							 & spell_peace_max!= 3
							 & spell_peace_max!= 4, cl(gwno);
#delimit cr
estimates store modelfrom1to4jnOLD


* Corroborate that the exclusion was correct
tab spell_peace_max if e(sample) == 1





*------------------------------------------------------------------------------*
* Model A exclude spells of max 5 years
*------------------------------------------------------------------------------*
version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10 & spell_peace_max!= 1 
							 & spell_peace_max!= 2 
							 & spell_peace_max!= 3
							 & spell_peace_max!= 4
							 & spell_peace_max!= 5, cl(gwno);
#delimit cr
estimates store modelfrom1to5jnOLD


* Corroborate that the exclusion was correct
tab spell_peace_max if e(sample) == 1



*------------------------------------------------------------------------------*
* Model A exclude spells of max > 5 years
*------------------------------------------------------------------------------*
version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   gov_change_L1
		   pko 
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10 & spell_peace_max<=10, cl(gwno)
;
#delimit cr
estimates store model10plusjnOLD


* Corroborate that the exclusion was correct
tab spell_peace_max if e(sample) == 1





*------------------------------------------------------------------------------*
* Export results in table: MODELS PGM OLD vs NEW
*------------------------------------------------------------------------------*
#delimit;													
esttab 	model1jnOLD 
		modelfrom1to2jnOLD 
		modelfrom1to3jnOLD 
		modelfrom1to4jnOLD 
		modelfrom1to5jnOLD 
		model10plusjnOLD
using "Tables/cg_robustness_jacknife_pgm_oldnew_RR_10.tex", replace 
b(3) se(3) 
order( 			  pgm_warlegacy_count   
				  pgm_new_postconf_count
				  pko 
				  xconst 	  
				  gov_change_L1
				  ptsL1_alt
				  media_free_lag 
				  rgdppc_log
				  pop_log 	  
				  peace_years 
				  peace_years2 
				  peace_years3
		) 
nobaselevels 
stats(chi2 aic N_clust N, star(chi2) fmt(2 2 0 0) 
labels("Wald $\chi^{2}$""AIC""Number of clusters""Number of observations")) 
coeflabels( pgm_warlegacy_count    "PGM inherited from conflict\$\_{count}\$"
			pgm_new_postconf_count "PGM new to post-conflict\$\_{count}\$"
			xconst                 "Executive constraints" 
			ptsL1_alt 	     	   "Physical integrity rights violations\$\_{lag}\$"
			media_free_lag 		   "Free media\$\_{lag}\$"
			pko              	   "PKO\$\_{presence}\$"
			gov_change_L1		   "Government change\$\_{lag}\$"
			pop_log      		   "Population\$\_{log}\$"
			rgdppc_log   		   "GDP\$\_{log}\$"
			peace_years  		   "Peace years" 
			peace_years2 		   "Peace years\$\_{^2}\$" 
			peace_years3 		   "Peace years\$\_{^3}\$" 
			cut1:_cons			   "Cut 1"
			cut2:_cons			   "Cut 2"
			) 
label 
star(\dag 0.10 * 0.05  ** 0.01) 
nonumber
nomtitles
eqlabels(,none)
nolegend 
nonotes 
booktabs 
alignment(D{.}{.}{-1}) 
compress
substitute(\_ _)
fragment
prehead(
\begin{table}[htbp]\centering
\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
		\caption{Order logit estimations for the level of human rights violations in post-conflict societies based on Model 4 in Table 1---step-wise exlusion of post-conflict episodes based on their total duration \label{tab:jack_rewold_RR}}
		\setlength{\tabcolsep}{0pt}
		\scalebox{.75}{		
		\begin{tabular}{l*{6}{D{.}{.}{-1}}}
		\hline \hline	
		\addlinespace
		& \multicolumn{6}{c}{\textit{Dependent variable}: Physical Integrity Rights Violations}\\ 
		\cmidrule(r{5pt}l{5pt}){2-7} 
        \addlinespace
		& \multicolumn{6}{c}{Excluding post-conflict episodes of maximum duration of (in years):}\\
		\addlinespace
		& \multicolumn{1}{c}{1} & \multicolumn{1}{c}{<=2} & \multicolumn{1}{c}{<=3} & \multicolumn{1}{c}{<=4} & \multicolumn{1}{c}{<=5} & \multicolumn{1}{c}{>10} \\
		)
		postfoot(
		\hline \hline
		\multicolumn{7}{l}{\footnotesize \textit{Note:} Values are coefficients with robust standard errors in parentheses, clustered on country.}\\
		\multicolumn{7}{l}{\footnotesize  $\dag$ p$<$0.1, * p$<$0.05, ** p$<$0.01 (two-tailed test).}\\
		\end{tabular}
		}
		\end{table}		
		);
#delimit cr


*------------------------------------------------------------------------------*
* End of do-file
*------------------------------------------------------------------------------*


